@@ -8,7 +8,7 @@ Some utilities.
 """
 
 from functools import partial
-import sys, corebio.seq
+import sys, corebio.seq, string
 
 
 def shorten(seq, length):
@@ -35,12 +35,26 @@ def strip_Ns(seq):
     )
 
 
+
+_translate_table = string.maketrans('acgt', 'NNNN')
+
+def lower_to_N(seq):
+    "Create a new sequence where lower case A,C,G,T are replaced with Ns. Useful for masking UCSC data."
+    return corebio.seq.Seq(
+        seq.translate(_translate_table),
+        name='%s (lower masked)' % seq.name,
+        description='%s (lower masked)' % seq.description,
+        alphabet=seq.alphabet,
+    )
+
+
+
 def open_fasta(fasta, default, mode):
     "Open a FASTA file or return default if fasta filename is '-'"
     if '-' == fasta:
         return default
     else:
         return open(fasta, mode)
-   
+
 open_input = partial(open_fasta, default=sys.stdin, mode='r')
 open_output = partial(open_fasta, default=sys.stdout, mode='w')
